Module camera

Module camera 

Provides a camera used by raytracer to shoot rays into the scene

Structs

Camera
Contains all data needed to describe a cameras position, field of view and where it is pointing
CameraConfig
Contains all needed parameters for constructing a camera