pub struct Aabb {
pub x: Interval,
pub y: Interval,
pub z: Interval,
}Expand description
Axis Aligned Bounding Box
Fields
x: IntervalX axis interval
y: Intervaly axis interval
z: Intervalz axis interval
Implementations
Sourceimpl Aabb
impl Aabb
Sourcepub fn new_from_2_points(a: Vec3, b: Vec3) -> Aabb
pub fn new_from_2_points(a: Vec3, b: Vec3) -> Aabb
Create a new aabb exactly encapsulating the two given points
Sourcepub fn new_from_3_points(a: Vec3, b: Vec3, c: Vec3) -> Aabb
pub fn new_from_3_points(a: Vec3, b: Vec3, c: Vec3) -> Aabb
Create a new aabb exactly encapsulating the three given points
Sourcepub fn combine(&self, a: &Aabb) -> Aabb
pub fn combine(&self, a: &Aabb) -> Aabb
Create a new aabb that is the sum of the two given aabb’s
Sourcepub fn pad_if_needed(&self) -> Aabb
pub fn pad_if_needed(&self) -> Aabb
Create a new aabb the same size as self. Except for axis that are very small, these are padded a bit