A wrapper for the random number generator to be used by ray tracer.
Functions
- Returns a random element from the given vector
- returns a random float min to <max
- returns a random float 0 to <1
- returns a random uint32 0 to <max
A wrapper for the random number generator to be used by ray tracer.