Module renderer

Module renderer 

The renderer takes a Scene as input, renders it and reports RenderProgress

Modules

gpu_data
GPU data structures matching WGSL layout
scene_flattener
Utilities for flattening the scene graph into linear buffers for the GPU

Structs

RenderConfig
Input to the ray tracer for how the image should be rendered
RenderProgress
Progress reported back to the caller of the raytrace function
Renderer
Renderer is a central part of the raytracer responsible for controlling the process reporting back progress to the caller
Scene
Contains all information needed to render an image

Enums

RenderImageStrategy
When should RenderProgress contain an image of the rendering