pub enum RenderImageStrategy {
EverySample,
Interval(Duration),
OnlyFinal,
}Expand description
When should RenderProgress contain an image of the rendering
Variants
EverySample
Every sample should contain an image
Interval(Duration)
Only include an image if at least “duration” has elapsed since last time Plus always include the final image
OnlyFinal
Only include image in last rendered sample
Implementations
Sourceimpl RenderImageStrategy
impl RenderImageStrategy
Sourcepub fn should_generate_image(
&self,
sample: u32,
total_samples: u32,
now: SystemTime,
last_image_generated_time: SystemTime,
) -> bool
pub fn should_generate_image( &self, sample: u32, total_samples: u32, now: SystemTime, last_image_generated_time: SystemTime, ) -> bool
Is it time to generate a new render image for the output channel?