pub struct RenderProgress {
pub progress: f64,
pub fps: Option<f64>,
pub estimated_time_left: Duration,
pub output_buffer: Buffer,
}Expand description
Progress reported back to the caller of the raytrace function
Fields
progress: f64progress is reported between 0 -> 1 and represents a percentage of completion
fps: Option<f64>Current speed of rendering in number of frames per second
estimated_time_left: DurationEstimated time left until rendering is complete
output_buffer: BufferOutput buffer containing the image data