Module solstrale::camera

source ·
Package camera provides a camera used by raytracer to shoot rays into the scene

Structs

  • Contains all data needed to describe a cameras position, field of view and where it is pointing
  • Contains all needed parameters for constructing a camera