Modules
Structs
- Input to the ray tracer for how the image should be rendered
- progress reported back to the caller of the raytrace function
- Renderer is a central part of the raytracer responsible for controlling the process reporting back progress to the caller
- Contains all information needed to render an image