Struct solstrale::renderer::RenderProgress
source · pub struct RenderProgress {
pub progress: f64,
pub render_image: RgbImage,
}Expand description
progress reported back to the caller of the raytrace function
Fields
progress: f64progress is reported between 0 -> 1 and represents a percentage of completion
render_image: RgbImageOutput image so far, will be final when progress is 1